--------------------------------------------------------------------------------
-- Library
--------------------------------------------------------------------------------
--! IEEE standard library
library ieee;
--! IEEE standard logic package
use ieee.std_logic_1164.all;

--------------------------------------------------------------------------------
-- Entity TC1SPW
--! \brief        TC1SPW - test case 1.
--! \details      The unit executes the test case 1.
-- Comments     :
-- Updates      :
--------------------------------------------------------------------------------
entity TC1SPW is
   generic (
      SEED           : integer      := 2     --! seed for random generation.
   );
   port (
      CONTROL_IN  : in execution; --! the test case execution control information.
      CONTROL_OUT : out result    --! the test case execution result information.
   );
end entity TC1SPW;

--------------------------------------------------------------------------------
-- Architecture TC1SPW_beh
--! \brief  Implementation of the test case 1.
--------------------------------------------------------------------------------
architecture TC1SPW_beh of TC1SPW is
   
begin
   -----------------------------------------------------------------------------
   -- Process genInputProc
   --! \brief        Generate input data for UUT.
   --! \details      The process generates the required signals for the data interface.
   -----------------------------------------------------------------------------
   genInputProc: process is

      variable RV              : RandomPType ;
      variable random_bit      : std_logic := '0';
      variable random_bit_vec  : std_logic_vector(0 downto 0);
      variable random_seq      : std_logic_vector(8 downto 0) := (others => '0'); 
      ----------------------------------------------------------------------------
      -- Procedure genBit
      -----------------------------------------------------------------------------
      procedure genBit(
         b: std_logic
      ) is
      begin
         spw_link.si <= not (spw_link.si xor spw_link.di xor b);
         spw_link.di <= b;
         wait for INBIT_PERIOD;
      end procedure genBit;
      -----------------------------------------------------------------------------
      -- Procedure genfct
      -----------------------------------------------------------------------------
      procedure genfct is
      begin
         genBit(input_par);
         genBit('1');
         genBit('0');
         input_par <= '0';
         genBit('0');
      end procedure genfct;
      -----------------------------------------------------------------------------
      -- Procedure genesc
      -----------------------------------------------------------------------------
      procedure genesc is
      begin
         genBit(input_par);
         genBit('1');
         genBit('1');
         input_par <= '0';
         genBit('1');
      end procedure genesc;

   begin
      -- initializing the generator with the seed
      RV.InitSeed(RV'instance_name & integer'image(SEED));
      input_idle <= '1';
      inputReset;
      wait until input_pattern /= 0;
      input_idle <= '0';
      while input_pattern /= 0 loop
         if input_pattern = 1 then
            -- NULL tokens
            genesc;
            genfct;
         else
             PrintFailureLine(GetExecutedTestCaseName, "genInputProc: ", " ", "Unknown input pattern selected!" );
         end if; -- input_pattern
      end loop;
   end process genInputProc;


end architecture TC1SPW_beh;

--------------------------------------------------------------------------------
-- end TC1SPW.vhd
--------------------------------------------------------------------------------
